@@ -175,6 +175,11 @@ int read_main_config_file(char *main_config_file) {
 				}
 			}
 
+		else if(!strcmp(variable, "website_url")) {
+			my_free(website_url);
+			website_url = strdup(value);
+			}
+
 		else if(!strcmp(variable, "loadctl_options"))
 			error = set_loadctl_options(value, strlen(value)) != OK;
 		else if(!strcmp(variable, "check_workers"))
@@ -924,7 +929,7 @@ int read_main_config_file(char *main_config_file) {
 		else if(!strcmp(variable, "status_update_interval")) {
 
 			status_update_interval = atoi(value);
-			if(status_update_interval <= 1) {
+			if(status_update_interval < 1) {
 				asprintf(&error_message, "Illegal value for status_update_interval");
 				error = TRUE;
 				break;
@@ -2222,7 +2227,7 @@ int pre_flight_circular_check(int *w, int *e) {
 		dep_type = temp_sd->dependency_type;
 		/*
 		 * this shouldn't happen, but it can in case dependencies are
-		 * added to services on hosts in empty hostgroups (ie, nonexistant)
+		 * added to services on hosts in empty hostgroups (ie, nonexistent)
 		 */
 		if(dep_type < 1 || dep_type > ARRAY_SIZE(ary))
 			continue;
