@@ -24,8 +24,8 @@
 
 #include "shared.h"
 
-#define PROGRAM_VERSION "4.2.2"
-#define PROGRAM_MODIFICATION_DATE "10-24-2016"
+#define PROGRAM_VERSION "4.3.3"
+#define PROGRAM_MODIFICATION_DATE "2017-08-12"
 
 NAGIOS_BEGIN_DECL
 
@@ -66,6 +66,7 @@ extern int obsess_over_hosts;
 extern int enable_timing_point;
 
 extern char *config_file_dir;
+extern char *website_url;
 
 #ifdef HAVE_TZNAME
 #ifdef CYGWIN
@@ -346,6 +347,10 @@ NAGIOS_END_DECL
 #define CMD_DEL_DOWNTIME_BY_HOSTGROUP_NAME              171
 #define CMD_DEL_DOWNTIME_BY_START_TIME_COMMENT          172
 
+/* new commands in Nagios 4.x found below... */
+#define CMD_CLEAR_HOST_FLAPPING_STATE                   173
+#define CMD_CLEAR_SVC_FLAPPING_STATE                    174
+
 /* custom command introduced in Nagios 3.x */
 #define CMD_CUSTOM_COMMAND                              999
 
